aboutgitcodebugslistschat
path: root/udp.h
diff options
context:
space:
mode:
Diffstat (limited to 'udp.h')
-rw-r--r--udp.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/udp.h b/udp.h
index 12a28dd..0b2ef22 100644
--- a/udp.h
+++ b/udp.h
@@ -38,15 +38,20 @@ union udp_epoll_ref {
/**
* struct udp_ctx - Execution context for UDP
* @port_to_tap: Ports bound host/init-side, packets to guest/tap
* @port_to_init: Ports bound namespace-side, spliced to init
* @port_to_ns: Ports bound init-side, spliced to namespace
* @timer_run: Timestamp of most recent timer run
*/
struct udp_ctx {
- uint8_t port_to_tap [USHRT_MAX / 8];
- uint8_t port_to_init [USHRT_MAX / 8];
- uint8_t port_to_ns [USHRT_MAX / 8];
+ uint8_t port4_to_tap [USHRT_MAX / 8];
+ uint8_t port6_to_tap [USHRT_MAX / 8];
+ uint8_t port4_to_init [USHRT_MAX / 8];
+ uint8_t port6_to_init [USHRT_MAX / 8];
+ uint8_t port4_to_ns [USHRT_MAX / 8];
+ uint8_t port6_to_ns [USHRT_MAX / 8];
struct timespec timer_run;
};
@@ -38,15 +38,20 @@ union udp_epoll_ref {
/**
* struct udp_ctx - Execution context for UDP
- * @port_to_tap: Ports bound host/init-side, packets to guest/tap
- * @port_to_init: Ports bound namespace-side, spliced to init
- * @port_to_ns: Ports bound init-side, spliced to namespace
+ * @port6_to_tap: IPv6 ports bound host/init-side, packets to guest/tap
+ * @port4_to_init: IPv4 ports bound namespace-side, spliced to init
+ * @port6_to_init: IPv6 ports bound namespace-side, spliced to init
+ * @port4_to_ns: IPv4 ports bound init-side, spliced to namespace
+ * @port6_to_ns: IPv6 ports bound init-side, spliced to namespace
* @timer_run: Timestamp of most recent timer run
*/